Remove some unnecessary includes.
[libdcp.git] / src / dcp.h
index d6275037c1582ce4719639b98ae4b4237c87c72f..05c2026bbd34e299b39892cd04cdbf1082360764 100644 (file)
--- a/src/dcp.h
+++ b/src/dcp.h
@@ -25,7 +25,7 @@
 #define LIBDCP_DCP_H
 
 #include "types.h"
-#include "certificates.h"
+#include "certificate.h"
 #include "metadata.h"
 #include <boost/shared_ptr.hpp>
 #include <boost/signals2.hpp>
@@ -41,34 +41,41 @@ namespace xmlpp {
 namespace dcp
 {
 
-class Content; 
+class Content;
 class Reel;
 class CPL;
 class XMLMetadata;
-class Signer;
-class KDM;
+class CertificateChain;
+class DecryptedKDM;
 class Asset;
-
-namespace parse {
-       class AssetMap;
-}
+class DCPReadError;
 
 /** @class DCP
  *  @brief A class to create or read a DCP.
  */
-       
+
 class DCP : public boost::noncopyable
 {
 public:
        /** Construct a DCP.  You can pass an existing DCP's directory
-        *  as the parameter, or a non-existant folder to create a new
-        *  DCP in.
+        *  as the parameter; alternatively, directory will be created
+        *  if it does not exist.  Note that if you pass an existing DCP
+        *  into this constructor it will not be read until you call ::read().
         *
         *  @param directory Directory containing the DCP's files.
         */
        DCP (boost::filesystem::path directory);
 
-       void read ();
+       typedef std::list<boost::shared_ptr<DCPReadError> > ReadErrors;
+
+       /** Read the DCP's structure into this object.
+        *  @param keep_going true to try to keep going in the face of (some) errors.
+        *  @param errors List of errors that will be added to if keep_going is true.
+        *  @param ignore_incorrect_picture_mxf_type true to try loading MXF files marked as monoscopic
+        *  as stereoscopic if the monoscopic load fails; fixes problems some 3D DCPs that (I think)
+        *  have an incorrect descriptor in their MXF.
+        */
+       void read (bool keep_going = false, ReadErrors* errors = 0, bool ignore_incorrect_picture_mxf_type = false);
 
        /** Compare this DCP with another, according to various options.
         *  @param other DCP to compare this one to.
@@ -76,27 +83,25 @@ public:
         *  @param note Functor to handle notes made by the equality operation.
         *  @return true if the DCPs are equal according to EqualityOptions, otherwise false.
         */
-       bool equals (DCP const & other, EqualityOptions options, boost::function<void (NoteType, std::string)> note) const;
+       bool equals (DCP const & other, EqualityOptions options, NoteHandler note) const;
 
-       void add (boost::shared_ptr<Asset> asset);
+       void add (boost::shared_ptr<CPL> cpl);
 
        std::list<boost::shared_ptr<CPL> > cpls () const;
-
-       /** @return All this DCP's assets (note that CPLs are assets) */
-       std::list<boost::shared_ptr<Asset> > assets () const {
-               return _assets;
-       }
+       std::list<boost::shared_ptr<Asset> > assets () const;
 
        bool encrypted () const;
 
-       void add (KDM const &);
+       void add (DecryptedKDM const &);
 
        void write_xml (
                Standard standard,
                XMLMetadata metadata = XMLMetadata (),
-               boost::shared_ptr<const Signer> signer = boost::shared_ptr<const Signer> ()
+               boost::shared_ptr<const CertificateChain> signer = boost::shared_ptr<const CertificateChain> ()
        );
 
+       void resolve_refs (std::list<boost::shared_ptr<Asset> > assets);
+
 private:
 
        /** Write the PKL file.
@@ -106,9 +111,9 @@ private:
                Standard standard,
                std::string pkl_uuid,
                XMLMetadata metadata,
-               boost::shared_ptr<const Signer> signer
+               boost::shared_ptr<const CertificateChain> signer
                ) const;
-       
+
        void write_volindex (Standard standard) const;
 
        /** Write the ASSETMAP file.
@@ -119,8 +124,8 @@ private:
 
        /** the directory that we are writing to */
        boost::filesystem::path _directory;
-       /** the assets that make up this DCP */
-       std::list<boost::shared_ptr<Asset> > _assets;
+       /** the CPLs that make up this DCP */
+       std::list<boost::shared_ptr<CPL> > _cpls;
 };
 
 }